<?php 

    require 'MyPDO.php';

    class User
    {
        private $login;
        private $mdp;

        private const USER_TABLE = "Users";


        public function __construct($log, $mot = NULL)
        {
            $this->login = $log;
            $this->mdp = $mot;
        }

        public function getLogin()
        {
            return $this->login;
        }

        public function getMdp()
        {
            return $this->mdp;
        }

        public function setLogin($nLogin)
        {
            $this->login = $nLogin;
        }

        public function setMdp($nMdp)
        {
            $this->mdp = $nMdp;
        }

        public function exists()
        {
            try 
            {
                $pdo = MyPDO::pdo();
            }
            catch( PDOException $e ) 
            {
                echo 'Erreur : '.$e->getMessage();
                exit;
            }

            
            $requete = $pdo->prepare("SELECT mdp FROM " . self::USER_TABLE . " WHERE login=:nomutil");
            $requete->bindvalue( ':nomutil', $this->login, PDO::PARAM_STR );

            $requete->execute();

            if (!$row = $requete->fetch() ) 
                return false;
            
            else
                $hash = strval($row['mdp']);

            if(password_verify($this->mdp, $hash))
                return true;

            else
                return false;

        }

        public function create()
        {
            try 
            {
                $pdo = MyPDO::pdo();
            }
            catch( PDOException $e )    
            {
                echo 'Erreur : '.$e->getMessage();
                exit;
            }
        
            $requete = $pdo->prepare("INSERT INTO ". self::USER_TABLE . " VALUES (:user , :motdepasse)");
            $requete->bindvalue( ':user', $this->login, PDO::PARAM_STR );
            $requete->bindvalue( ':motdepasse', password_hash($this->mdp,PASSWORD_DEFAULT), PDO::PARAM_STR );
            $res = $requete->execute();
        
            if($res)
            {
                unset($_SESSION['erreur']);
                header("Location: ./signin.php");
                exit;
            }
            else
            {
                throw new Exception("L'utilisateur existe déjà");
            }
        }

        public function changePassword($nPassword)
        {
            try 
            {
                $pdo = MyPDO::pdo();
            }
            catch( PDOException $e ) 
            {
                echo 'Erreur : '.$e->getMessage();
                exit;
            }


            $requete = $pdo->prepare("UPDATE " . self::USER_TABLE . " SET mdp = :motdepasse WHERE login = :user;");
            $requete->bindvalue( ':user', $this->login, PDO::PARAM_STR );
            $requete->bindvalue( ':motdepasse', password_hash($nPassword,PASSWORD_DEFAULT), PDO::PARAM_STR );
            $res = $requete->execute();

            if(!$res)
            {
                throw new Exception("Impossible de changer le mdp dans la bdd");
            }
            else
            {
                $_SESSION['message'] = "Mot de passe changé";
                $this->setMdp($nPassword);
                header('Location: ./account.php');
                exit;
            }
        }

        public function delete()
        {
            try 
            {
                $pdo = MyPDO::pdo();
            }
            catch( PDOException $e ) 
            {
                throw new Exception('Erreur : '.$e->getMessage() );
            }

            $requete = $pdo->prepare("DELETE FROM ". self::USER_TABLE ." WHERE login = :user");
            $requete->bindvalue( ':user', $_SESSION['login'], PDO::PARAM_STR );
            $res = $requete->execute();

            if(!$res)
            {
                throw new Exception("Impossible de supprimer le compte");   
            }
            else
            {
                session_unset();
                header('Location: ./account.php');
                exit;
            }
        }

    }







?>